@@ -41,8 +41,6 @@ import copy
 import math
 import pytz
 import ephem
-import weakref
-from textwrap import fill as tw_fill
 from datetime import datetime, timedelta
 
 from astropy import units as astrounits
@@ -50,23 +48,25 @@ from astropy.coordinates import Angle as AstroAngle
 
 from lsl.transform import Time
 from lsl.astro import utcjd_to_unix, MJD_OFFSET, DJD_OFFSET
-from lsl.astro import date as astroDate, get_date as astroGetDate
 from lsl.common.color import colorfy
 
 from lsl.common.mcsADP import datetime_to_mjdmpm, mjdmpm_to_datetime
-from lsl.common.adp import freq_to_word, word_to_freq, fC
+from lsl.common.adp import freq_to_word, word_to_freq
 from lsl.common.stations import LWAStation, get_full_stations, lwa1
 from lsl.reader.drx import FILTER_CODES as DRXFilters
 from lsl.reader.drx import FRAME_SIZE as DRXSize
-from lsl.common.sdf import Observer
+from lsl.common.sdf import UCF_USERNAME_RE, Observer
 from lsl.common import sdf, sdfADP
 
+from lsl.config import LSL_CONFIG
+OBSV_CONFIG = LSL_CONFIG.view('observing')
+
 from lsl.misc import telemetry
 telemetry.track_module()
 
 
-__version__ = '0.1'
-__all__ = ['Observer', 'ProjectOffice', 'Project', 'Run', 'Scan', 'DRX', 'Solar', 'Jovian', 'parse_idf',  'get_scan_start_stop', 'is_valid', '__version__']
+__version__ = '0.2'
+__all__ = ['UCF_USERNAME_RE', 'Observer', 'ProjectOffice', 'Project', 'Run', 'Scan', 'DRX', 'Solar', 'Jovian', 'parse_idf',  'get_scan_start_stop', 'is_valid', '__version__']
 
 
 _UTC = pytz.utc
@@ -120,6 +120,15 @@ class Project(object):
     def __str__(self):
         return "%s: %s with %i run(s) for %s" % (self.id, self.name, len(self.runs), str(self.observer))
         
+    @classmethod
+    def autofilled(cls, runs=None, comments=None, project_office=None):
+        observer = Observer.autofilled()
+        name = OBSV_CONFIG.get('project_name')
+        id = OBSV_CONFIG.get('project_id')
+        if name is None or id is None:
+            raise RuntimeError("Auto-fill values for the project cannot be loaded from the configuration file")
+        return cls(observer, name, id, runs=runs, comments=comments, project_office=project_office)
+        
     def update(self):
         """Update the various runs that are part of this project."""
         
@@ -222,7 +231,7 @@ class Project(object):
         if ses.ucf_username is not None:
             clean = ''
             if ses.comments:
-                clean = sdf._usernameRE.sub('', ses.comments)
+                clean = UCF_USERNAME_RE.sub('', ses.comments)
             ses.comments = 'ucfuser:%s' % ses.ucf_username
             if len(clean) > 0:
                 ses.comments += ';;%s' % clean
@@ -232,74 +241,74 @@ class Project(object):
             
         ## PI Information
         output = ""
-        output = "%sPI_ID            %s\n" % (output, self.observer.id)
-        output = "%sPI_NAME          %s\n" % (output, self.observer.name)
-        output = "%s\n" % output
+        output += "PI_ID            %s\n" % (self.observer.id,)
+        output += "PI_NAME          %s\n" % (self.observer.name,)
+        output += "\n"
         
         ## Project Information
-        output = "%sPROJECT_ID       %s\n" % (output, self.id)
-        output = "%sPROJECT_TITLE    %s\n" % (output, self.name)
-        output = "%sPROJECT_REMPI    %s\n" % (output, self.comments[:4090] if self.comments else 'None provided')
-        output = "%sPROJECT_REMPO    %s\n" % (output, self.project_office.project)
-        output = "%s\n" % output
+        output += "PROJECT_ID       %s\n" % (self.id,)
+        output += "PROJECT_TITLE    %s\n" % (self.name,)
+        output += "PROJECT_REMPI    %s\n" % (self.comments[:4090] if self.comments else 'None provided',)
+        output += "PROJECT_REMPO    %s\n" % (self.project_office.project,)
+        output += "\n"
         
         ## Run Information
-        output = "%sRUN_ID           %s\n" % (output, ses.id)
-        output = "%sRUN_TITLE        %s\n" % (output, 'None provided' if ses.name is None else ses.name)
-        output = "%sRUN_STATIONS     %s\n" % (output, ','.join([station.id for station in ses.stations]))
-        output = "%sRUN_CHANNELS     %i\n" % (output, ses.correlator_channels)
-        output = "%sRUN_INTTIME      %.3f\n" % (output, ses.correlator_inttime)
-        output = "%sRUN_BASIS        %s\n" % (output, ses.correlator_basis)
-        output = "%sRUN_REMPI        %s\n" % (output, ses.comments[:4090] if ses.comments else 'None provided')
-        output = "%sRUN_REMPO        %s\n" % (output, "Requested data return method is %s" % ses.dataReturnMethod if pos == 'None' or pos is None else pos[:4090])
-        output = "%s\n" % output
+        output += "RUN_ID           %s\n" % (ses.id,)
+        output += "RUN_TITLE        %s\n" % ('None provided' if ses.name is None else ses.name,)
+        output += "RUN_STATIONS     %s\n" % (','.join([station.id for station in ses.stations]),)
+        output += "RUN_CHANNELS     %i\n" % (ses.correlator_channels,)
+        output += "RUN_INTTIME      %.3f\n" % (ses.correlator_inttime,)
+        output += "RUN_BASIS        %s\n" % (ses.correlator_basis,)
+        output += "RUN_REMPI        %s\n" % (ses.comments[:4090] if ses.comments else 'None provided',)
+        output += "RUN_REMPO        %s\n" % ("Requested data return method is %s" % ses.dataReturnMethod if pos == 'None' or pos is None else pos[:4090],)
+        output += "\n"
                     
         ## Scans
         for i,obs in enumerate(ses.scans):
             obsID = i + 1
             
-            output = "%sSCAN_ID          %i\n" % (output, obsID)
-            output = "%sSCAN_TARGET      %s\n" % (output, obs.target)
-            output = "%sSCAN_INTENT      %s\n" % (output, obs.intent)
-            output = "%sSCAN_REMPI       %s\n" % (output, obs.comments[:4090] if obs.comments else 'None provided')
-            output = "%sSCAN_REMPO       %s\n" % (output, "Estimated raw data volume for this scan is %s per station; %s total" % (self._render_file_size(obs.dataVolumeStation), self._render_file_size(obs.dataVolume)) if poo[i] == 'None' or poo[i] == None else poo[i])
-            output = "%sSCAN_START_MJD   %i\n" % (output, obs.mjd)
-            output = "%sSCAN_START_MPM   %i\n" % (output, obs.mpm)
-            output = "%sSCAN_START       %s\n" % (output, obs.start.strftime("%Z %Y/%m/%d %H:%M:%S") if isinstance(obs.start, datetime) else obs.start)
-            output = "%sSCAN_DUR         %i\n" % (output, obs.dur)
-            output = "%sSCAN_DUR+        %s\n" % (output, obs.duration)
-            output = "%sSCAN_MODE        %s\n" % (output, obs.mode)
+            output += "SCAN_ID          %i\n" % (obsID,)
+            output += "SCAN_TARGET      %s\n" % (obs.target,)
+            output += "SCAN_INTENT      %s\n" % (obs.intent,)
+            output += "SCAN_REMPI       %s\n" % (obs.comments[:4090] if obs.comments else 'None provided',)
+            output += "SCAN_REMPO       %s\n" % ("Estimated raw data volume for this scan is %s per station; %s total" % (self._render_file_size(obs.dataVolumeStation), self._render_file_size(obs.dataVolume)) if poo[i] == 'None' or poo[i] is None else poo[i],)
+            output += "SCAN_START_MJD   %i\n" % (obs.mjd,)
+            output += "SCAN_START_MPM   %i\n" % (obs.mpm,)
+            output += "SCAN_START       %s\n" % (obs.start.strftime("%Z %Y/%m/%d %H:%M:%S") if isinstance(obs.start, datetime) else obs.start,)
+            output += "SCAN_DUR         %i\n" % (obs.dur,)
+            output += "SCAN_DUR+        %s\n" % (obs.duration,)
+            output += "SCAN_MODE        %s\n" % (obs.mode,)
             if obs.mode == 'TRK_RADEC':
-                output = "%sSCAN_RA          %.9f\n" % (output, obs.ra)
-                output = "%sSCAN_DEC         %+.9f\n" % (output, obs.dec)
+                output += "SCAN_RA          %.9f\n" % (obs.ra,)
+                output += "SCAN_DEC         %+.9f\n" % (obs.dec,)
                 if obs.pm[0] != 0.0 or obs.pm[1] != 0.0:
-                    output = "%sSCAN_PM_RA       %+.1f\n" % (output, obs.pm[0])
-                    output = "%sSCAN_PM_DEC      %+.1f\n" % (output, obs.pm[1])
-            output = "%sSCAN_FREQ1       %i\n" % (output, obs.freq1)
-            output = "%sSCAN_FREQ1+      %.9f MHz\n" % (output, obs.frequency1/1e6)
-            output = "%sSCAN_FREQ2       %i\n" % (output, obs.freq2)
-            output = "%sSCAN_FREQ2+      %.9f MHz\n" % (output, obs.frequency2/1e6)
-            output = "%sSCAN_BW          %i\n" % (output, obs.filter)
-            output = "%sSCAN_BW+         %s\n" % (output, self._render_bandwidth(obs.filter, obs.FILTER_CODES))
+                    output += "SCAN_PM_RA       %+.1f\n" % (obs.pm[0],)
+                    output += "SCAN_PM_DEC      %+.1f\n" % (obs.pm[1],)
+            output += "SCAN_FREQ1       %i\n" % (obs.freq1,)
+            output += "SCAN_FREQ1+      %.9f MHz\n" % (obs.frequency1/1e6,)
+            output += "SCAN_FREQ2       %i\n" % (obs.freq2,)
+            output += "SCAN_FREQ2+      %.9f MHz\n" % (obs.frequency2/1e6,)
+            output += "SCAN_BW          %i\n" % (obs.filter,)
+            output += "SCAN_BW+         %s\n" % (self._render_bandwidth(obs.filter, obs.FILTER_CODES),)
             ## Alternate phase centers
             if len(obs.alt_phase_centers) > 0:
-                output = "%sSCAN_ALT_N             %i\n" % (output, len(obs.alt_phase_centers))
-                for i,phase_center in enumerate(obs.alt_phase_centers):
-                    output = "%sSCAN_ALT_TARGET[%i]    %s\n" % (output, i+1, phase_center.target)  
-                    output = "%sSCAN_ALT_INTENT[%i]    %s\n" % (output, i+1, phase_center.intent) 
-                    output = "%sSCAN_ALT_RA[%i]        %.9f\n" % (output, i+1, phase_center.ra)  
-                    output = "%sSCAN_ALT_DEC[%i]       %+.9f\n" % (output, i+1, phase_center.dec)
+                output += "SCAN_ALT_N             %i\n" % (len(obs.alt_phase_centers),)
+                for j,phase_center in enumerate(obs.alt_phase_centers):
+                    output += "SCAN_ALT_TARGET[%i]    %s\n" % (j+1, phase_center.target)  
+                    output += "SCAN_ALT_INTENT[%i]    %s\n" % (j+1, phase_center.intent) 
+                    output += "SCAN_ALT_RA[%i]        %.9f\n" % (j+1, phase_center.ra)  
+                    output += "SCAN_ALT_DEC[%i]       %+.9f\n" % (j+1, phase_center.dec)
                     if phase_center.pm[0] != 0.0 or phase_center.pm[1] != 0.0:
-                        output = "%sSCAN_ALT_PM_RA[%i]       %+.1f\n" % (output, i+1, phase_center.pm[0])
-                        output = "%sSCAN_ALT_PM_DEC[%i]      %+.1f\n" % (output, i+1, phase_center.pm[1])
+                        output += "SCAN_ALT_PM_RA[%i]       %+.1f\n" % (j+1, phase_center.pm[0])
+                        output += "SCAN_ALT_PM_DEC[%i]      %+.1f\n" % (j+1, phase_center.pm[1])
                         
             ## ASP filter setting
             if obs.asp_filter != -1:
-                output = "%sSCAN_ASP_FLT     %i\n" % (output, obs.asp_filter)
+                output += "SCAN_ASP_FLT     %i\n" % (obs.asp_filter,)
             ## DRX gain
             if obs.gain != -1:
-                output = "%sSCAN_DRX_GAIN    %i\n" % (output, obs.gain)
-            output = "%s\n" % output
+                output += "SCAN_DRX_GAIN    %i\n" % (obs.gain,)
+            output += "\n"
             
         return output
         
@@ -552,10 +561,6 @@ class Run(object):
                 print("[%i] Error: Invalid run ID number '%i'" % (os.getpid(), self.id))
             failures += 1
             
-        if len(self.stations) < 2:
-            if verbose:
-                print("[%i] Error: Need at least two stations to form an interferometer" % (os.getpid(),))
-            failures += 1
         station_count = {}
         for station in self.stations:
             try:
@@ -567,19 +572,7 @@ class Run(object):
                 if verbose:
                     print("[%i] Error: Station '%s' is included %i times" % (os.getpid(), station, station_count[station]))
                 failures += 1
-        if self.correlator_inttime < 0.1 or self.correlator_inttime > 10.0:
-            if verbose:
-                print("[%i] Error: Invalid correlator integration time '%.3f s'" % (os.getpid(), self.correlator_inttime))
-            failures += 1
-        if self.correlator_channels < 16 or self.correlator_channels > 32768 or self.correlator_channels % 2:
-            if verbose:
-                print("[%i] Error: Invalid correlator channel count '%i'" % (os.getpid(), self.correlator_channels))
-            failures += 1
-        if self.correlator_basis.lower() not in (None, '', 'linear', 'circular', 'stokes'):
-            if verbose:
-                print("[%i] Error: Invalid correlator output polarization basis '%s'" % (os.getpid(), self.correlator_basis))
-            failures += 1
-            
+                
         scanCount = 1
         for obs in self.scans:
             if verbose:
@@ -735,7 +728,7 @@ class Scan(object):
         
         self.gain = int(gain)
         
-        self.alt_phase_centers = []
+        self.alt_phase_centers = sdf._TypedParentList(AlternatePhaseCenter, self)
         
         self.update()
         
@@ -839,6 +832,8 @@ class Scan(object):
             value = value * 12.0/math.pi
         elif isinstance(value, AstroAngle):
             value = value.to('hourangle').value
+        elif isinstance(value, str):
+            value = AstroAngle(value).to('hourangle').value
         if value < 0.0 or value >= 24.0:
             raise ValueError("Invalid value for RA '%.6f' hr" % value)
         self._ra = value
@@ -854,6 +849,8 @@ class Scan(object):
             value = value * 180.0/math.pi
         elif isinstance(value, AstroAngle):
             value = value.to('deg').value
+        elif isinstance(value, str):
+            value = AstroAngle(value).to('deg').value
         if value < -90.0 or value > 90.0:
             raise ValueError("Invalid value for dec. '%.6f' deg" % value)
         self._dec = value
@@ -987,10 +984,6 @@ class Scan(object):
         
         failures = 0
         # Basic - Intent, duration, frequency, and filter code values
-        if self.intent.lower() not in ('fluxcal', 'phasecal', 'target', 'dummy'):
-            if verbose:
-                print("[%s] Error: Invalid scan intent '%s'" % (os.getpid(), self.intent))
-            failures += 1
         if self.dur < 1:
             if verbose:
                 print("[%i] Error: Specified a duration of length zero" % os.getpid())
@@ -1009,14 +1002,6 @@ class Scan(object):
             failures += 1
             
         # Advanced - Target Visibility
-        if self.ra < 0 or self.ra >= 24:
-            if verbose:
-                print("[%i] Error: Invalid value for RA '%.6f'" % (os.getpid(), self.ra))
-            failures += 1
-        if self.dec < -90 or self.dec > 90:
-            if verbose:
-                print("[%i] Error: Invalid value for dec. '%+.6f'" % (os.getpid(), self.dec))
-            failures += 1
         if self.target_visibility < 1.0:
             if verbose:
                 print("[%i] Error: Target is only above the horizon for %.1f%% of the scan" % (os.getpid(), self.target_visibility*100.0))
@@ -1228,6 +1213,8 @@ class AlternatePhaseCenter(object):
             value = value * 12.0/math.pi
         elif isinstance(value, AstroAngle):
             value = value.to('hourangle').value
+        elif isinstance(value, str):
+            value = AstroAngle(value).to('hourangle').value
         if value < 0.0 or value >= 24.0:
             raise ValueError("Invalid value for RA '%.6f' hr" % value)
         self._ra = value
@@ -1244,6 +1231,8 @@ class AlternatePhaseCenter(object):
             value = value * 180.0/math.pi
         elif isinstance(value, AstroAngle):
             value = value.to('deg').value
+        elif isinstance(value, str):
+            value = AstroAngle(value).to('deg').value
         if value < -90.0 or value > 90.0:
             raise ValueError("Invalid value for dec. '%.6f' deg" % value)
         self._dec = value
@@ -1284,29 +1273,61 @@ class AlternatePhaseCenter(object):
         pnt._pmdec = self.pm[1]
         pnt._epoch = ephem.J2000
         return pnt
-    
+        
+    @property
+    def target_visibility(self):
+        """Return the fractional visibility of the target during the scan 
+        period."""
+        
+        mjd, mpm, dur = 0, 0, 0
+        stations = [lwa1,]
+        if self._parent is not None:
+            mjd = self._parent.mjd
+            mpm = self._parent.mpm
+            dur = self._parent.dur
+            if self._parent._parent is not None:
+                stations = self._parent._parent.stations
+                
+        vis_list = []
+        max_alt = 0.0
+        for station in stations:
+            lwa = station.get_observer()
+            pnt = self.fixed_body
+            
+            vis = 0
+            cnt = 0
+            dt = 0.0
+            while dt <= dur/1000.0:
+                lwa.date = mjd + (mpm/1000.0 + dt)/3600/24.0 + MJD_OFFSET - DJD_OFFSET
+                pnt.compute(lwa)
+                max_alt = max([max_alt, pnt.alt])
+                
+                cnt += 1
+                if pnt.alt > 0:
+                    vis += 1
+                    
+                dt += 300.0
+                
+            vis_list.append(float(vis)/float(cnt))
+            
+        if max_alt < 20*math.pi/180:
+            #warnings.warn("Maximum altitude for this scan is %.1f degrees" % (max_alt*180/math.pi))
+            pass
+            
+        return min(vis_list)
+        
     def validate(self, verbose=False):
         """Basic validation of the pointing, that's it."""
         
         failures = 0
         
-        ## Intent
-        if self.intent.lower() not in ('fluxcal', 'phasecal', 'target'):
+        ## Advanced - Target Visibility
+        if self.target_visibility < 1.0:
             if verbose:
-                print("[%s] Error: Invalid alternate phase center intent '%s'" % (os.getpid(), self.intent))
+                print("[%i] Error: Target is only above the horizon for %.1f%% of the scan" % (os.getpid(), self.target_visibility*100.0))
             failures += 1
             
-        ## Pointing
-        if self.ra < 0 or self.ra >= 24:
-            if verbose:
-                print("[%i] Error: Invalid alternate phase center value for RA '%.6f'" % (os.getpid(), self.ra))
-            failures += 1
-        if self.dec < -90 or self.dec > 90:
-            if verbose:
-                print("[%i] Error: Invalid alternate phase center value for dec. '%+.6f'" % (os.getpid(), self.dec))
-            failures += 1
-            
-        # Any failures indicates a bad scan
+        # Any failures indicates a bad alternate phase center
         if failures == 0:
             return True
         else:
@@ -1381,9 +1402,6 @@ def parse_idf(filename, verbose=False):
     # in the keywords
     kwdRE = re.compile(r'(?P<keyword>[A-Z_0-9\+]+)(\[(?P<id1>[0-9]+?)\])?(\[(?P<id2>[0-9]+?)\])?(\[(?P<id3>[0-9]+?)\])?(\[(?P<id4>[0-9]+?)\])?')
     
-    # Create the metatag regular expression to deal with spectrometer mode settings
-    metaRE = re.compile(r'\{.*\}')
-    
     # Create empty objects to get things started.  Values will get filled in as they
     # are found in the file
     po = ProjectOffice()
@@ -1484,12 +1502,12 @@ def parse_idf(filename, verbose=False):
                 project.runs[0].correlator_basis = value
                 continue
             if keyword == 'RUN_REMPI':
-                mtch = sdf._usernameRE.search(value)
+                mtch = UCF_USERNAME_RE.search(value)
                 if mtch is not None:
                     project.runs[0].ucf_username = mtch.group('username')
                     if mtch.group('subdir') is not None:
                         project.runs[0].ucf_username = os.path.join(project.runs[0].ucf_username, mtch.group('subdir'))
-                project.runs[0].comments = sdf._usernameRE.sub('', value)
+                project.runs[0].comments = UCF_USERNAME_RE.sub('', value)
                 continue
             if keyword == 'RUN_REMPO':
                 project.project_office.runs.append(None)
