@@ -11,7 +11,6 @@ if sys.version_info < (3,):
 import os
 import re
 import imp
-import copy
 import numpy
 import ephem
 import struct
@@ -29,7 +28,7 @@ from lsl.misc import telemetry
 telemetry.track_module()
 
 
-__version__ = '2.2'
+__version__ = '2.3'
 __all__ = ['geo_to_ecef', 'ecef_to_geo', 'LWAStation', 'Antenna', 'Stand', 'FEE', 'Cable', 'ARX', 'LSLInterface', 
         'parse_ssmif', 'lwa1', 'lwavl', 'lwana', 'lwasv',  'get_full_stations']
 
@@ -73,7 +72,6 @@ def ecef_to_geo(x, y, z):
     
     # Longitude
     lon = numpy.arctan2(y, x)
-    p = numpy.sqrt(x**2 + y**2)
     
     # Latitude (first approximation)
     lat = numpy.arctan2(z, p)
@@ -210,6 +208,10 @@ class LWAStation(ephem.Observer, LWAStationBase):
      * pols:  A list of polarizations
      * cables: A list of cables
     
+    .. versionchanged:: 2.1.0
+        Added new 'beamformer_min_delay' and 'beamformer_min_delay_samples' attributes
+        that can be used to help track the station's minimum beamformer delay.
+    
     .. versionchanged:: 1.2.0
         Added a new 'interface' attribute which provides referenves to various modules
         to help interface with the station.
@@ -234,6 +236,9 @@ class LWAStation(ephem.Observer, LWAStationBase):
         self.pressure = 0.0
         self.horizon = 0.0
         
+        self.beamformer_min_delay = None
+        self.beamformer_min_delay_samples = None
+        
     def __str__(self):
         return "%s (%s) at lat: %.3f, lng: %.3f, elev: %.1f m with %i antennas" % (self.name, self.id, self.lat*180.0/numpy.pi, self.long*180.0/numpy.pi, self.elev, len(self.antennas))
         
@@ -1014,6 +1019,7 @@ class LSLInterface(object):
                 raise RuntimeError("Unknown module for interface type '%s'" % which)
             modInfo = imp.find_module(value.split('.')[-1], [os.path.dirname(__file__)])
             self._cache[which] = imp.load_module(value, *modInfo)
+            modInfo[0].close()
         return self._cache[which]
 
 
@@ -1857,18 +1863,18 @@ def parse_ssmif(filename):
     return station
 
 
-# LWAVL
+#: LWAVL
 _ssmifvl = os.path.join(dataPath, 'lwa1-ssmif.txt')
 lwavl = parse_ssmif(_ssmifvl)
 
-# LWAVL is also known as LWA1
+#: LWAVL is also known as LWA1
 lwa1 = lwavl
 
-# LWANA
+#: LWANA
 _ssmifna = os.path.join(dataPath, 'lwana-ssmif.txt')
 lwana = parse_ssmif(_ssmifna)
 
-# LWASV
+#: LWASV
 _ssmifsv = os.path.join(dataPath, 'lwasv-ssmif.txt')
 lwasv = parse_ssmif(_ssmifsv)
 
