@@ -50,13 +50,13 @@ from astropy.io import fits as astrofits
 import shutil
 import tarfile
 import tempfile
+import warnings
 try:
     from StringIO import StringIO
 except ImportError:
     from io import StringIO
 from calendar import timegm
 from datetime import datetime
-from operator import itemgetter
 from astropy.constants import c as vLight
 
 from lsl import astro
@@ -123,24 +123,21 @@ def CorrelatedData(filename, verbose=False):
         except Exception as e:
             if verbose:
                 print("FITSIDI - ERROR: %s" % str(e))
-            pass
-            
+                
         ## UVFITS
         try:
             return CorrelatedDataUV(filename)
         except Exception as e:
             if verbose:
                 print("UVFITS - ERROR: %s" % str(e))
-            pass
-            
+                
         ## Measurment Set as a compressed entity
         try:
             return CorrelatedDataMS(filename)
         except Exception as e:
             if verbose:
                 print("MS - ERROR: %s" % str(e))
-            pass
-            
+                
     if not valid:
         raise RuntimeError("File '%s' does not appear to be either a FITS IDI file, UV FITS file, or MeasurmentSet" % filename)
 
@@ -406,9 +403,6 @@ class CorrelatedDataIDI(CorrelatedDataBase):
         hdulist = astrofits.open(self.filename)
         uvData = hdulist['UV_DATA']
         
-        # We need this a lot...
-        nPol = len(self.pols)
-        
         dataSets = VisibilityData()
         try:
             len(sets)
@@ -478,7 +472,7 @@ class CorrelatedDataIDI(CorrelatedDataBase):
             if seperateWeights:
                 if wgt.shape != nFreq*nStk:
                     ## Catch for some old stuff
-                    wgt = numpy.concatenate([wgt for pol in self.pols])
+                    wgt = numpy.concatenate([wgt,]*len(self.pols))
                 wgt.shape = (wgt.size//nFreq//nStk, nFreq, nStk)
             else:
                 try:
@@ -702,9 +696,6 @@ class CorrelatedDataUV(CorrelatedDataBase):
         hdulist = astrofits.open(self.filename)
         uvData = hdulist[0]
         
-        # We need this a lot...
-        nPol = len(self.pols)
-        
         dataSets = VisibilityData()
         try:
             len(sets)
@@ -822,7 +813,7 @@ try:
     from casacore.tables import table
     
     # Stokes codes for CASA Measurement Sets
-    NUMERIC_STOKESMS = { 1:'I',   2:'Q',   3:'U',   4:'V', 
+    NUMERIC_STOKESMS = {1:'I',   2:'Q',   3:'U',   4:'V', 
                         5:'RR',  6:'RL',  7:'LR',  8:'LL',
                         9:'XX', 10:'XY', 11:'YX', 12:'YY'}
     
@@ -900,7 +891,8 @@ try:
             try:
                 src = table(os.path.join(self.filename, 'SOURCE'), ack=False)
             except:
-                raise RuntimeError("Cannot find table 'SOURCE' in '%s'" % self.filename)
+                src = None
+                warnings.warn("Cannot find table 'SOURCE' in '%s', assuming zenith is the only source" % self.filename, RuntimeWarning)
             try:
                 fld = table(os.path.join(self.filename, 'FIELD'), ack=False)
             except:
@@ -980,8 +972,11 @@ try:
             
             # Data set sources
             self._sources = []
-            for sdir,name in zip(src.col('DIRECTION'), src.col('NAME')):
-                self._sources.append( aipy.amp.RadioFixedBody(*sdir, name=name) )
+            if src is not None:
+                for sdir,name in zip(src.col('DIRECTION'), src.col('NAME')):
+                    self._sources.append( aipy.amp.RadioFixedBody(*sdir, name=name) )
+            else:
+                self._sources.append('z')
                 
             # Data set fields
             self._fields = []
@@ -1002,7 +997,8 @@ try:
             ants.close()
             pols.close()
             obs.close()
-            src.close()
+            if src is not None:
+                src.close()
             fld.close()
             spw.close()
             dsc.close()
@@ -1023,9 +1019,6 @@ try:
             # Open the data table
             data = table(self.filename, ack=False)
             
-            # We need this a lot...
-            nPol = len(self.pols)
-            
             dataSets = VisibilityData()
             try:
                 len(sets)
@@ -1037,7 +1030,7 @@ try:
                 targetJD = targetTime / 3600.0 / 24.0 + astro.MJD_OFFSET
                 
                 # Pull out the data
-                targetData = data.query('TIME == %.16f' % targetTime, sortlist='DATA_DESC_ID,ANTENNA1,ANTENNA2')
+                targetData = data.query('TIME == %.16f AND FLAG_ROW == false' % targetTime, sortlist='DATA_DESC_ID,ANTENNA1,ANTENNA2')
                 uvw  = targetData.getcol('UVW')
                 try:
                     wgt  = None
@@ -1047,7 +1040,10 @@ try:
                     wgtS = None
                 ant1 = targetData.getcol('ANTENNA1')
                 ant2 = targetData.getcol('ANTENNA2')
-                vis  = targetData.getcol('DATA')
+                try:
+                    vis = targetData.getcol('CORRECTED_DATA')
+                except RuntimeError:
+                    vis  = targetData.getcol('DATA')
                 fld  = targetData.getcol('FIELD_ID')
                 dsc  = targetData.getcol('DATA_DESC_ID')
                 
@@ -1100,7 +1096,7 @@ try:
                     
                     # Deal with multiple spectral windows
                     # NOTE: This assumes that the data are stored in an array that 
-                    #       is window, basline per the lsl.writer.measurementset 
+                    #       is window, baseline per the lsl.writer.measurementset 
                     #       module
                     if len(self._windows) > 1:
                         nBand = len(self._windows)
@@ -1135,7 +1131,6 @@ try:
             return dataSets
             
 except ImportError:
-    import warnings
     warnings.warn('Cannot import casacore.tables, MS support disabled', ImportWarning)
     
     class CorrelatedDataMS(object):
@@ -1157,26 +1152,6 @@ class ImgWPlus(aipy.img.ImgW):
     the field of view and the pixels near the phase center.
     """
     
-    def __init__(self, size=100, res=1, wres=.5, mf_order=0):
-        """
-        size = number of wavelengths which the UV matrix spans (this 
-        determines the image resolution).
-        res = resolution of the UV matrix (determines image field of view).
-        wres: the gridding resolution of sqrt(w) when projecting to w=0.
-        """
-        
-        self.res = float(res)
-        self.size = float(size)
-        ## Small change needed to work with Numpy 1.12+
-        dim = numpy.int64(numpy.round(self.size / self.res))
-        self.shape = (dim,dim)
-        self.uv = numpy.zeros(shape=self.shape, dtype=numpy.complex64)
-        self.bm = []
-        for i in range(mf_order+1):
-            self.bm.append(numpy.zeros(shape=self.shape, dtype=numpy.complex64))
-        self.wres = float(wres)
-        self.wcache = {}
-        
     def __iadd__(self, uv, bm=None):
         if isinstance(uv, ImgWPlus):
             if self.shape != uv.shape:
@@ -1395,7 +1370,7 @@ class ImgWPlus(aipy.img.ImgW):
                 
             data = data*taper1*taper2
             
-        return aipy.img.recenter(ifft2Function(data).real.astype(numpy.float32), center)
+        return aipy.img.recenter(ifft2Function(data).real.astype(numpy.float32)/self.kern_corr, center)
         
     def image(self, center=(0,0), weighting='natural', local_fraction=0.5, robust=0.0, taper=(0.0, 0.0)):
         """Return the inverse FFT of the UV matrix, with the 0,0 point moved
@@ -1478,7 +1453,7 @@ def build_gridded_image(data_set, size=80, res=0.50, wres=0.10, pol='XX', chan=N
     if chan is not None:
         # Make sure that `chan' is an array by trying to find its length
         try:
-            junk = len(chan)
+            len(chan)
         except TypeError:
             chan = [chan]
             
@@ -1507,7 +1482,7 @@ def build_gridded_image(data_set, size=80, res=0.50, wres=0.10, pol='XX', chan=N
     if wgt.dtype != numpy.complex64:
         wgt = wgt.astype(numpy.complex64)
         
-    im.uv, im.bm[0] = WProjection(u, v, w, vis, wgt, size, numpy.float64(res), numpy.float64(wres))
+    im.uv, im.bm[0], im.kern_corr = WProjection(u, v, w, vis, wgt, size, numpy.float64(res), numpy.float64(wres))
     
     if not verbose:
         sys.stdout.close()
@@ -1616,14 +1591,6 @@ def get_image_azalt(gimg, aa, phase_center='z', shifted=True):
     .. versionadded: 1.1.0
     """
     
-    # Get the phase center
-    if phase_center is not 'z':
-        phase_center.compute(aa)
-        pcRA, pcDec = phase_center.ra, phase_center.dec
-    else:
-        pcRA, pcDec = aa.sidereal_time(), aa.lat
-    rot = aipy.coord.eq2top_m(0, pcDec)
-    
     # Get the RA and dec. coordinates for each pixel
     ra, dec = get_image_radec(gimg, aa, phase_center=phase_center, shifted=shifted)
     
