@@ -60,9 +60,9 @@ __all__ = ['FrameHeader', 'FramePayload', 'Frame', 'read_frame', 'get_data_produ
            'is_stokes', 'get_sample_rate', 'get_frame_size', 'get_ffts_per_integration', 
            'get_transform_size', 'get_integration_time', 'FILTER_CODES']
 
-# List of filter codes and their corresponding sample rates in Hz.  
-# .. note::
-#		These are just the DRX filter codes
+#: List of filter codes and their corresponding sample rates in Hz.  
+#: .. note::
+#:		These are just the DRX filter codes
 FILTER_CODES = drx_FILTER_CODES
 
 
@@ -109,9 +109,9 @@ class FrameHeader(FrameHeaderBase):
         if self.format & 0x01:
             products.append('XX')
         if self.format & 0x02:
-            products.append('XY')
+            products.append('XY_real')
         if self.format & 0x04:
-            products.append('YX')
+            products.append('XY_imag')
         if self.format & 0x08:
             products.append('YY')
             
@@ -171,8 +171,7 @@ class FrameHeader(FrameHeaderBase):
         """
         
         sampleCodes = {}
-        for key in FILTER_CODES:
-            value = FILTER_CODES[key]
+        for key,value in FILTER_CODES.items():
             sampleCodes[value] = key
             
         return sampleCodes[self.sample_rate]
@@ -228,7 +227,7 @@ class FramePayload(FramePayloadBase):
     def data(self):
         packed = []
         dtype = []
-        for p in ('XX', 'XY', 'YX', 'YY', 'I', 'Q', 'U', 'V'):
+        for p in ('XX', 'XY_real', 'XY_imag', 'YY', 'I', 'Q', 'U', 'V'):
             for t in (0, 1):
                 sub = getattr(self, "%s%i" % (p, t), None)
                 if sub is not None:
@@ -254,8 +253,8 @@ class Frame(FrameBase):
     .. versionchanged:: 0.6.0
         By default the data contained with in a frame is normalized by the number of
         fills (header.fills parameter).  For data products that are a function of more
-        than one primary input, i.e., XY* or I, the minimum fill of X and Y are used 
-        for normalization.
+        than one primary input, i.e., real(XY*) or I, the minimum fill of X and Y are 
+        used for normalization.
     """
     
     _header_class = FrameHeader
