@@ -18,7 +18,7 @@ except ImportError:
     
 from lsl.common import busy
 
-__version__  = "0.1"
+__version__  = "0.2"
 __author__    = "Jayce Dowell"
 
 
@@ -26,7 +26,7 @@ class busy_tests(unittest.TestCase):
     """A unittest.TestCase collection of unit tests for the regressions in LSL."""
     
     def test_default(self):
-        """Test the busy indicator, default options."""
+        """Test the standard busy indicator, default options."""
         
         bi = busy.BusyIndicator()
         
@@ -38,8 +38,21 @@ class busy_tests(unittest.TestCase):
         
         sys.stdout = sys.__stdout__
         
+    def test_color(self):
+        """Test the standard busy indicator, default options and color."""
+        
+        bi = busy.BusyIndicator(color='green')
+        
+        sys.stdout = StringIO()
+        
+        bi.start()
+        time.sleep(1)
+        bi.stop()
+        
+        sys.stdout = sys.__stdout__
+        
     def test_context(self):
-        """Test the busy indicator as a context manager."""
+        """Test the standard busy indicator as a context manager."""
         
         sys.stdout = StringIO()
         
@@ -47,6 +60,21 @@ class busy_tests(unittest.TestCase):
             time.sleep(1)
             
         sys.stdout = sys.__stdout__
+        
+    def test_styles(self):
+        """Test the various styles of the busy indicator plus."""
+        
+        for style in ('boomerang', 'pingpong', 'flow'):
+            for color in (None, 'red'):
+                sys.stdout = StringIO()
+                
+                with busy.BusyIndicatorPlus(style=style, color=color) as bi:
+                    time.sleep(1)
+                    
+                sys.stdout = sys.__stdout__
+                
+        with self.assertRaises(ValueError):
+            busy.BusyIndicatorPlus(style='testing?')
 
 
 class busy_test_suite(unittest.TestSuite):
